@@ -1307,9 +1307,23 @@ _wrap_g_struct_info_is_foreign (PyGIBaseInfo *self)
     return pygi_gboolean_to_py (g_struct_info_is_foreign (self->info));
 }
 
+static PyObject *
+_wrap_g_struct_info_find_method (PyGIBaseInfo *self, PyObject *py_name)
+{
+    return _get_child_info_by_name (self, py_name, g_struct_info_find_method);
+}
+
+static PyObject *
+_wrap_g_struct_info_find_field (PyGIBaseInfo *self, PyObject *py_name)
+{
+    return _get_child_info_by_name (self, py_name, g_struct_info_find_field);
+}
+
 static PyMethodDef _PyGIStructInfo_methods[] = {
     { "get_fields", (PyCFunction) _wrap_g_struct_info_get_fields, METH_NOARGS },
+    { "find_field", (PyCFunction) _wrap_g_struct_info_find_field, METH_O },
     { "get_methods", (PyCFunction) _wrap_g_struct_info_get_methods, METH_NOARGS },
+    { "find_method", (PyCFunction) _wrap_g_struct_info_find_method, METH_O },
     { "get_size", (PyCFunction) _wrap_g_struct_info_get_size, METH_NOARGS },
     { "get_alignment", (PyCFunction) _wrap_g_struct_info_get_alignment, METH_NOARGS },
     { "is_gtype_struct", (PyCFunction) _wrap_g_struct_info_is_gtype_struct, METH_NOARGS },
@@ -2229,10 +2243,17 @@ _wrap_g_union_info_get_size (PyGIBaseInfo *self)
     return pygi_gsize_to_py (g_union_info_get_size (self->info));
 }
 
+static PyObject *
+_wrap_g_union_info_get_alignment (PyGIBaseInfo *self)
+{
+    return pygi_gsize_to_py (g_union_info_get_alignment (self->info));
+}
+
 static PyMethodDef _PyGIUnionInfo_methods[] = {
     { "get_fields", (PyCFunction) _wrap_g_union_info_get_fields, METH_NOARGS },
     { "get_methods", (PyCFunction) _wrap_g_union_info_get_methods, METH_NOARGS },
     { "get_size", (PyCFunction) _wrap_g_union_info_get_size, METH_NOARGS },
+    { "get_alignment", (PyCFunction) _wrap_g_union_info_get_alignment, METH_NOARGS },
     { NULL, NULL, 0 }
 };
 
